Please [fork the repository][ForkARepo], make your changes, commit them and 
then create a [pull request][PullRequest] in the original repository.

Also please keep the structure:

  - Put different sections into different files and `\input` them from the 
  `contents.tex` file.
  - Break lines at 80 columns. (Preferable: Lines that should continue to the 
  next line should be broken at 80 columns with a whitespace as final 
  character.)

Keep the general file structure outlined in README.md, this makes the material 
more modular and compatible.

[ForkARepo]: https://help.github.com/articles/fork-a-repo/
[PullRequest]: https://help.github.com/articles/using-pull-requests/
